##  Basic Auth
![Setting up Basic Auth](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2744e26c7a4410148473bf040578c543_LowRes.png)
Setting up Basic Auth
To configure this authentication method, it is recommended to create a dedicated user in Collibra and use those credentials.
  * Collibra Domain: Your Collibra instance domain without schema or trailing slashes. For example, if your Collibra instance is accessed on the browser via [<https://my-own.collibra.com>], then just enter <my-own.collibra.com>
  * Username: The username of the user in Collibra that is being used for this integration.
  * Password: The password of the user
